@@ -11,7 +11,6 @@ use Moose                     ();
 use MooseX::StrictConstructor ();
 use mro                       ();
 use namespace::autoclean      ();
-use Moose::Util 'throw_exception';
 use Module::Load 'load';
 use MooseX::Extended::Core qw(
   _assert_import_list_is_valid
@@ -28,7 +27,7 @@ no warnings _disabled_warnings();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 sub import {
     my ( $class, %args ) = @_;
@@ -126,7 +125,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
@@ -201,7 +200,7 @@ It also exports two functions which are similar to Moose C<has>: C<param> and
 C<field>.
 
 A C<param> is a required parameter (defaults may be used). A C<field> is not
-allowed to be passed to the constructor.
+intended to be passed to the constructor.
 
 Note that the C<has> function is still available, even if it's not needed.
 
@@ -419,7 +418,9 @@ and C<field> attributes, both of which are C<< is => 'ro' >> by default.
 The C<param> is I<required>, whether by passing it to the constructor, or using
 C<default> or C<builder>.
 
-The C<field> is I<forbidden> in the constructor and lazy by default.
+The C<field> is I<forbidden> in the constructor and is lazy if it has a
+builder, because that builder is often dependent on attributes set in the
+constructor (and why call it if it's not used?).
 
 Here's a short example:
 
@@ -485,7 +486,9 @@ if it encounters an illegal method name for an attribute.
 This also applies to various attributes which allow method names, such as
 C<clone>, C<builder>, C<clearer>, C<writer>, C<reader>, and C<predicate>.
 
-Trying to pass a defined C<init_arg> to C<field> will also this exception.
+Trying to pass a defined C<init_arg> to C<field> will also throw this
+exception, unless the init_arg begins with an underscore. (It is sometimes
+useful to be able to define an C<init_arg> for unit testing.)
 
 =head1 DEBUGGER SUPPORT
 
