@@ -28,7 +28,7 @@ use Ref::Util qw(
 );
 use Carp 'croak';
 
-our $VERSION = '0.21';
+our $VERSION = '0.22';
 
 our @EXPORT_OK = qw(
   _assert_import_list_is_valid
@@ -254,15 +254,18 @@ sub field ( $meta, $name, %opt_for ) {
     foreach my $attr ( is_plain_arrayref($name) ? @$name : $name ) {
         my %options = %opt_for;    # copy each time to avoid overwriting
         if ( defined( my $init_arg = $options{init_arg} ) ) {
-            throw_exception(
+            $init_arg =~ /\A_/ or throw_exception(
                 'InvalidAttributeDefinition',
                 attribute_name => $name,
                 class_name     => $meta->name,
-                messsage       => "The 'field.init_arg' must be absent or undef, not '$init_arg'",
+                messsage       => "A defined 'field.init_arg' must begin with an underscore: '$init_arg'",
             );
         }
-        $options{init_arg} = undef;
-        $options{lazy} //= 1;
+
+        $options{init_arg} //= undef;
+        if ( $options{builder} || $options{default} ) {
+            $options{lazy} //= 1;
+        }
 
         _add_attribute( 'field', $meta, $attr, %options );
     }
@@ -442,7 +445,7 @@ MooseX::Extended::Core - Internal module for MooseX::Extended
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 DESCRIPTION
 
